@@ -76,9 +76,8 @@ of the namespace portion :mod:`ae.gui_help`.
 
 
 """
-from typing import cast, Tuple
+from typing import cast
 
-from kivy.animation import Animation                                                        # type: ignore
 from kivy.input import MotionEvent                                                          # type: ignore
 from kivy.lang import Builder                                                               # type: ignore
 # pylint: disable=no-name-in-module
@@ -93,7 +92,7 @@ from ae.gui_help import HelpAppBase
 from ae.kivy_relief_canvas import ReliefCanvas                                              # type: ignore
 
 
-__version__ = '0.1.9'
+__version__ = '0.1.10'
 
 
 Builder.load_string("""\
@@ -209,8 +208,6 @@ class HelpLayout(ScrollView):
     ps_hints = ObjectProperty()         #: pos- and size-hints for the layout window widget
     help_text = StringProperty()        #: help text string to display
 
-    ani_slide_back = None               # used for slide back animation if target position to the help activator
-
     def _update_effect_bounds(self, *args):
         """ override to prevent ScrollView recursion error/crash.
 
@@ -227,51 +224,6 @@ class HelpLayout(ScrollView):
         """
         return False        # let user click through this transparent help text widget
 
-    def begin_ani_slide_back(self, end_pos: Tuple[float, float]):
-        """ create and start animation for the help target widget (just displayed new help text for).
-
-        :param end_pos:         position (x, y) to move help target widget to (mostly the help_activator position).
-        """
-        tar = self.target
-        beg_pos = tuple(tar.pos)        # tuple() to de-ref pos property because it is changing too on animation
-        print(f"begin_ani_slide_back(win_end_pos={end_pos})")
-        end_pos = tar.to_widget(*end_pos)
-        print(f"begin_ani_slide_back(tar_end_pos={end_pos})")
-        delta = tar.height / 2
-        ani = Animation(x=min(max(beg_pos[0] - delta, end_pos[0]), beg_pos[0] + delta),
-                        y=min(max(beg_pos[1] - delta, end_pos[1]), beg_pos[1] + delta),
-                        t='in_out_sine', d=69)
-        ani += Animation(x=end_pos[0], y=end_pos[1], t='in_elastic', d=3)
-        self.ani_slide_back = dict(tar=tar, ani=ani, beg_pos=beg_pos)
-
-        ani.bind(on_complete=self.on_ani_slide_back_complete)
-        ani.start(tar)
-
-    def cancel_ani_slide_back(self):
-        """ cancel animation of help target widget.
-        """
-        if not self.ani_slide_back:
-            return
-
-        tar = self.ani_slide_back['tar']
-        ani = self.ani_slide_back['ani']
-        ani.cancel(tar)
-        ani.unbind(on_complete=self.on_ani_slide_back_complete)
-        tar.pos = self.ani_slide_back['beg_pos']
-        self.ani_slide_back = None
-
-    def on_ani_slide_back_complete(self, _ani: Animation, _target: Widget):
-        """ on-complete handler for help target pos animation.
-
-        :param _ani:            :class:`~kivy.animation.Animation` instance.
-        :param _target:         animated help target widget instance.
-        """
-        self.cancel_ani_slide_back()
-
-        main_app = cast(HelpAppBase, main_app_instance())
-        if main_app.help_layout:
-            main_app.help_display('', dict())
-
 
 class HelpToggler(ReliefCanvas, Image):                                                               # pragma: no cover
     """ widget for to activate and deactivate the help mode.
